@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay;
-$XML::Grammar::Screenplay::VERSION = '0.26.0';
+$XML::Grammar::Screenplay::VERSION = '0.26.1';
 use warnings;
 use strict;
 
@@ -19,7 +19,7 @@ screenplays.
 
 =head1 VERSION
 
-version 0.26.0
+version 0.26.1
 
 =head1 SYNOPSIS
 
@@ -182,6 +182,10 @@ L<http://www.shlomifish.org/humour/Selina-Mandrake/>
 
 L<http://www.shlomifish.org/humour/Summerschool-at-the-NSA/>
 
+=item * B<More:>
+
+L<https://www.shlomifish.org/open-source/projects/XML-Grammar/Fiction/#screenplay_examples>
+
 =back
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
